Synapse
=======

Synapse is a versatile central intelligence system created to support analyst teams in every stage of the intelligence life cycle.

|codecov|_ |circleci|_ |rtd|_

Learn More About Synapse
------------------------

* Visit our website_ to learn more about Synapse. 
* Attend a Synapse 101 training_! 


Installation & Documentation
----------------------------

* Synapse is available as a Python Package on pypi_ and as a Docker image on dockerhub_.

  * The Getting Started guide_ will help get you up and running!

* You can also use synapse_quickstart_ to get up and running quickly on Windows, Mac, or Linux and start using Synapse!
* User Guides and API Documentation can be found here_.

Connect With Us
---------------

* Join the Synapse user community on Slack_
* Follow us on Twitter_.
* Follow us on LinkedIn_.

.. |circleci| image:: https://circleci.com/gh/vertexproject/synapse/tree/master.svg?style=svg
..  _circleci: https://v.vtx.lk/synapse-circleci

.. |codecov| image:: https://codecov.io/gh/vertexproject/synapse/branch/master/graph/badge.svg?branch=master
.. _codecov: https://v.vtx.lk/synapse-codecov

.. |rtd| image:: https://readthedocs.com/projects/vertex-synapse/badge/?version=latest
.. _rtd: https://v.vtx.lk/synapse-docs

.. _slack: https://v.vtx.lk/join-slack

.. _dockerhub: https://v.vtx.lk/synapse-dockerhub

.. _guide: https://synapse.docs.vertex.link/en/latest/synapse/quickstart.html

.. _synapse_quickstart: https://github.com/vertexproject/synapse-quickstart

.. _pypi: https://v.vtx.lk/synapse-pypi

.. _website: https://v.vtx.lk/vertex

.. _training: https://v.vtx.lk/luma

.. _Twitter: https://v.vtx.lk/twitter

.. _LinkedIn: https://www.linkedin.com/company/vertexproject

.. _here: https://v.vtx.lk/synapse-docs
